@@ -2,14 +2,14 @@
 #
 use strict ;
 
-use App::Framework::Modules::Script ;
+use App::Framework ;
 
 # VERSION
 our $VERSION = '1.000' ;
 
 
 	# Create application and run it
-	App::Framework::Modules::Script->new()->go() ;
+	App::Framework->new()->go() ;
 
 #=================================================================================
 # SUBROUTINES EXECUTED BY APP
@@ -25,6 +25,8 @@ sub run
 	# Get source/dest dirs
 	my ($src_dir, $backup_dir) = @{$app->arglist()};
 	
+	
+	# do something useful....
 }
 
 
@@ -44,7 +46,7 @@ __DATA__
 
 [SUMMARY]
 
-Back up rip convert control files
+An example of using the application framework with named arguments
 
 [NAMEARGS]
 
@@ -52,6 +54,6 @@ src_dir:id backup_dir:id
 
 [DESCRIPTION]
 
-B<$name> scans through a directory (and it's subdirectories) looking for rip control files. Stores
-any files it finds in a replica of the directory structure, but located under the backup directory.
+B<$name> expects a source directory and destination directory to be specified. If not, then
+an error message is created and the application aborted.
 
